Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolFilesReaderInterface", Runnable);
;//5.0.1-v7 Mon Jan 19 16:58:39 CST 2026
